
# q-expansion of newform 200.6.d.c, downloaded from the LMFDB on 08 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 200
weight = 6
poly_data = [1125899906842624, -35184372088832, 0, -4466765987840, 154618822656, 52344913920, -12918456320, -1839202304, 688390144, -133857280, 25763840, -4183040, 672256, -56128, -12320, 1560, 144, -130, 0, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[22310269604040015872, -5482796095765479424, 281206420995571712, 14609533120806912, -2577927686324224, -351691987746816, -130895371567104, -54568964587520, 27054251540480, -7456044851200, 938905492480, -57990638080, -4572674112, 218821600, 24387512, 8659888, 8154694, -4445008, 764979, -483], 64985535248072704], [[-398995353455726428160, -230088366201661030400, 45579205457922228224, 53046568454971195392, 376714213004935168, 30103151436627968, -28739450357940224, 3247765273444352, -133891967713280, -218514883715072, 62967359482880, -6363604240896, 688009786560, -81286003872, -10966962984, 3798304176, -1019195218, 26166864, 16221639, -4229911], 56927328877311688704], [[739551224090507345920, -230088366201661030400, 45579205457922228224, -3880760422340493312, 376714213004935168, 30103151436627968, -28739450357940224, 3247765273444352, -133891967713280, -218514883715072, 62967359482880, -6363604240896, 688009786560, -81286003872, -10966962984, 3798304176, -1019195218, 26166864, 16221639, -4229911], 56927328877311688704], [[-14155643205950579408896, 2032562387000619958272, -302759495561908322304, 53369085228629360640, -11293428409155190784, -587284376174198784, 631647666851282944, -96356527653257216, 3668985925697536, 2147646760542208, -312151996392448, 43213138693632, -9032257383488, 1469926212320, -46439091272, -115848275856, -3755295802, 1522508560, 200668563, 8184925], 56927328877311688704], [[-290537608943622946816, -36920278847741493248, 14380522887603814400, -1667823929470746624, 201671035223801856, -37383033761824768, 1533798065897472, 2282444525928448, -384974644740096, 43756021800960, 6846008343552, -2829592035840, 220001324480, -28162083872, 8337406712, 273018864, -275463210, 98067728, -1635429, -749483], 3557958054831980544], [[7317357969240336891904, -5027909854874224820224, -497373711735969546240, 161481221831321976832, -22734442081994932224, 3166004538993803264, -642284034430337024, 29261371882340352, 39016181366882304, -6409133408460800, 929683365379072, 33191595752960, -35755969643072, 2640214152160, -432032034568, 145078992368, 4745284950, -4475752944, 1494251867, -37460587], 56927328877311688704], [[4862890454862952136704, -840860284847415885824, 97897437151293865984, 944161786653835264, -3315317822103486464, 783645889863352320, -163680950111174656, 8403251271303168, 2465012016971776, -799253857730560, 183217971594240, -20680896342016, 22800787008, 560953123424, -82143796184, 17928499712, -3174987598, -422469496, 28980305, -2398297], 3557958054831980544], [[2028471374713525895168, 116651030284383289344, -4356569221652545536, 30259198980154982400, -2817359731490816000, 1066706769977278464, 93483245485686784, -5943159302389760, 2555593425190912, -1079185086439424, 7028270535680, -12885313562112, -8464092379328, -337756795744, 24319978408, -8242278192, 1215292658, -662660240, 53322057, -21942713], 28463664438655844352], [[-67845321011452968960, 26925357511443742720, -1814298227118178304, -504104387455483904, 144673950704599040, -16732553843048448, 2151486609948672, -488903992672256, -65971747127296, 37800479170560, -6415320349696, 135214092800, 102695401024, -22625062880, 3641090696, -369264496, 50179594, 9206448, -3945067, 310971], 389913211488436224], [[32985348833280, 0, 3367254360064, -154618822656, -52344913920, 12918456320, 1839202304, -688390144, 133857280, -25763840, 4183040, -672256, 56128, 12320, -1560, -144, 130, 0, 1, -1], 1099511627776], [[8512297495420597174272, -1524933916928159776768, -219771797994381246464, 39145369054381867008, 23837592765230743552, -5492577721647104, 74094694516129792, -58399589063983104, 15599019171217408, -2523221400657920, 41635741543424, 29054858012160, -7202890789696, 727570551136, -1182708520, -17382640848, 10871437742, -2862289648, 267036039, 26933865], 28463664438655844352], [[1782857506304458489856, 8343823531029922054144, -732605312682023714816, 85311183198586142720, 10865189952501579776, -5694377504689618944, 1327183802759380992, -256438272407896064, 9762922076733440, 3063360199794688, -712476082338816, 200478553088512, -16791327420864, -872187338208, 1048063122568, -114873680624, 32934036874, -5836560656, -907077867, -70351621], 56927328877311688704], [[44695773317598883610624, -11739517946818906292224, 165826208861912039424, -30555914940373270528, 2514678097131864064, 4663778597113167872, -1006132674275835904, 167897679206023168, 29405809154031616, -10765179283513344, 900464157457408, -97971838181888, 13553542429120, 688611320288, -563937774472, 276237706480, -28225934410, -2662156528, 852814731, 155908709], 56927328877311688704], [[-8717136793150242684928, -822576593950059003904, 677473910841797509120, -23934758584804442112, -1845424287561809920, 27128748272779264, -51679483352055808, 52167909132206080, -4540694985932800, -1612312930803712, 515029132211200, -125026264149504, 7669236450624, 800828182176, -107152509720, 1694222736, -7014813950, 606126096, 354763953, -115985345], 14231832219327922176], [[-121865718122316520488960, 1512321929219336568832, 1569882298205488545792, 92081470645557264384, -23527941618721095680, 2383743702783754240, -118759100428320768, 206987422084366336, -73553368558960640, -1758271429861376, 932279985357824, -177138203377152, 28811244499520, 11873827935264, 1137047102728, -97345080816, -16030306774, 13939980272, 2441369189, -552184661], 56927328877311688704], [[-889374583956566966272, 19758997750034953404416, -4617241311784403468288, 240322255167506350080, 9776493899559206912, -1597365833330327552, -189583742558273536, -154331763272843264, -40446783040749568, 22527477651709952, -6366984431283200, 792268813650432, -48297338815680, -3310255442784, 116672831784, 10769589840, 15396948178, 7062341040, -3858273543, 622153303], 56927328877311688704], [[-112868675540266411622400, 7109345346812511256576, 2814482011973379686400, -213774124625080352768, -15190320161186906112, 756148458326327296, 415060774765985792, 284586807407935488, -121082347080744960, 11738943788425216, 781946658989056, -502697104182784, 39853210492992, 1045264526112, -406111665976, 74997660560, -34290812454, 18301120880, 55925949, -490769197], 28463664438655844352]]

hecke_ring_character_values = [[151, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [101, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [177, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-10, 1, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 2, 1, 0, 0, -1, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 15, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0], [0, 14, -6, 0, 1, -2, 0, 3, -1, -1, 0, 1, 0, -1, 0, 0, 0, 0, 0, 0], [-3, 34, -2, 0, -2, 7, 0, -1, 0, 0, 0, 0, -1, -1, 1, 0, 1, 0, 1, -1], [-359, 59, 8, -1, -1, 1, -1, -5, 1, -1, 0, 2, 4, -1, -1, 0, 0, -1, -2, -1], [1, -133, 5, 0, -8, -24, 0, 6, -2, 2, 0, 0, 1, 0, 2, 2, -1, 0, -2, 2], [363, -131, 3, 3, -1, 11, 1, -17, 7, 1, -4, -2, -3, -1, 1, 2, 2, -1, 4, 1], [9, 11, -57, 0, -6, 54, 0, -26, 4, -2, 0, 0, 3, 3, 2, -2, -2, 1, -3, 2], [-285, -172, -45, 6, 18, -2, 2, 22, 12, 0, -4, 2, 3, -2, 2, -2, 2, -4, -2, -2], [17, -106, -51, -8, 12, -34, -8, 15, -8, 0, -1, 0, 6, 2, -6, 0, -2, -4, 6, -2], [2243, 84, 28, -6, 29, 45, -1, -75, -11, -5, 4, -6, -5, -3, 7, 14, -2, 1, -4, -1], [54, -14, -170, -16, 46, -230, -16, -52, -6, 4, -16, 0, 10, 1, -12, -12, -5, -1, -3, 4], [53, -586, -244, -8, -64, 98, -8, -85, -10, 2, -1, 0, 15, 8, 18, -2, -10, -4, -2, 6], [-39, 493, 174, 16, -14, -134, 16, -76, -2, 4, -16, 0, -30, -9, 12, -12, 6, 1, 3, -4], [-118, 32, -64, -8, -78, -33, -8, 202, -2, 10, 1, 0, -20, -7, 17, 38, -19, 4, -11, 7], [-361, 1648, -266, 14, 41, 81, 27, -159, -11, 3, 12, 26, 33, 9, 11, 26, -6, 1, -16, -5], [-5296, 457, 669, -100, -30, -56, -52, 86, -18, -10, 16, 19, 44, -2, -20, -24, -8, -4, -32, -12], [-462, 1375, 336, -23, 130, -88, -28, 286, -28, -28, -4, 72, 25, -30, 20, -14, 2, 2, 10, 4], [82, -96, -935, -64, 58, -29, -64, 34, 44, 4, -1, 0, 83, -19, -9, 12, 31, 24, -33, 9], [-82, 514, 694, 92, 71, 190, -52, -315, -23, -15, 16, 15, 12, -7, 12, 40, -8, -4, -32, -12], [-3888, 3322, 815, -182, 90, -134, -50, 398, 48, -4, -12, 24, 177, -10, -2, -54, 6, -20, -22, -14], [-167, 4423, 601, 80, 70, 498, 80, -262, 44, -14, 112, 0, -179, 29, -18, -30, -32, 15, -45, 30], [-4693, 6120, 2034, -134, -7, 109, -121, -199, -83, -45, 12, 122, 145, -39, -1, 26, -6, 13, 8, 7], [-504, 6316, -586, -56, -42, 675, -56, 372, -38, -2, -19, 0, -124, 11, -13, 50, 103, -20, 31, -11], [179, 1149, -1329, -96, 122, -786, -96, -34, -12, 14, 128, 0, 3, 27, -54, 14, -60, 1, -43, 42], [7591, -3887, 1913, 116, 143, 86, -140, 125, -47, 9, 16, -54, -140, 17, 36, -8, -8, 20, 16, 12], [32269, -10239, 337, -37, -211, 1, -93, -211, 1, -65, -36, -430, -219, -83, -53, 2, 18, -15, 24, 3], [568, -11796, 2430, 128, 46, 1498, 128, 140, -6, -26, 17, 0, 420, 43, -33, -6, 271, -16, 15, 1], [-15099, 10979, 1059, 520, -481, -22, -88, -323, 1, -15, -32, 12, 328, -31, -88, -16, 16, 8, 64, 24], [910, -7248, -1394, -176, 430, -1485, -176, -58, -66, 2, 19, 0, 302, -13, -133, -50, -101, -32, 75, -43], [-187, 9779, -1745, -176, 616, -2272, -176, -414, -22, 54, -400, 0, -157, -80, -122, -154, 27, 16, -6, -10], [-56380, 20839, -250, 245, -568, -362, 110, 404, 238, 98, -116, 492, 637, 40, -90, -118, 58, -12, 150, 46], [788, -11432, -904, -96, 46, 4026, -96, 532, 86, -56, 288, 0, 520, -27, -36, 104, 101, 15, 53, -68], [975, -11758, -2600, -184, -312, 2695, -184, -383, -62, -26, 17, 0, 641, -20, 98, -6, 334, -44, 134, -90], [-138663, -10158, 591, -86, -199, -981, -83, 1653, -161, -7, 128, 1294, -404, 57, -123, -256, -64, 13, -166, -51], [-640, 16130, -2465, -112, -420, -3824, -112, -402, -162, 134, 752, 0, -641, -30, 106, 118, 38, -14, -76, 90], [1009, -20494, 558, -120, 34, -921, -120, 1067, -204, 68, 18, 0, 663, 85, -109, 140, 119, -68, -17, 85], [-2522, 37682, 1122, 16, 50, 4278, 16, 812, -298, 108, 464, 0, -1434, -41, -76, 124, 57, -95, 123, -28], [79141, 45093, 98, -203, 483, -447, 23, 1479, 285, 43, -80, -1094, 1824, 3, 47, -168, 40, -81, -42, -41], [-77240, -24175, -1882, 1830, -168, 282, -86, -936, 42, -66, 52, 421, -679, -40, -102, 42, -26, -80, -238, -106], [696, -32816, 3754, 64, -130, -7422, 64, 2176, 130, 92, -352, 0, 898, -299, 96, 252, 65, 111, -15, -96], [89370, 14554, -292, 18, -194, 978, 14, -2250, 194, -98, -128, -1084, 680, -162, -18, 256, 64, -82, 28, -18], [4698, -59680, -139, -128, 594, -2077, -128, -1814, 124, 52, -125, 0, 2167, -247, 11, -292, 403, 88, 19, -107], [87286, 34308, -5145, 86, -1568, -1470, 314, 1140, -310, -90, -76, -828, 851, -128, -254, -170, 38, 148, 410, 186], [-2365, 39554, 1976, 248, -460, -1382, 248, -1531, -314, 114, 143, 0, -1679, -62, 200, -178, 12, -100, 148, -48], [-1494, 12870, 3166, 304, -620, 5116, 304, -316, -264, 44, -560, 0, -850, 302, 92, -68, -364, -110, -126, 236], [37970, -53131, -6644, -3002, -227, -744, 498, 631, -463, 133, 348, -392, -1741, 307, -62, -66, -174, 124, -274, -50], [35169, 21236, 621, 780, 1269, 1839, 489, -1247, 411, 653, -112, 710, -24, 597, 593, 344, 56, 177, 522, 233], [-58736, -70353, 5159, -2820, -232, 268, -452, -1384, -608, -344, 256, 867, -2248, -216, -164, 128, -128, 4, -376, -124], [4669, -66406, -6850, -264, -1550, 16179, -264, -753, 316, -436, 654, 0, 2827, 213, 371, 164, 335, -60, 343, -283], [53396, 41781, -575, -3456, 669, 182, 496, 311, 603, 27, -368, 352, 1396, -157, 208, 104, 184, -104, 344, 80], [-147165, 66969, -11463, 387, -957, -901, 937, -117, -537, 193, 388, 766, 1563, 387, -167, -2, -194, 171, -240, -23], [-2614, 13772, 7033, 608, -1772, -19064, 608, -66, -158, 346, 224, 0, -1779, -462, 714, 186, -680, 94, -72, -22], [110887, 95115, 11662, 847, -1467, 243, -611, -663, -261, 245, 32, -2074, 2924, 261, -131, -96, -16, 237, 426, 221], [2057, -54839, 4614, 368, -2876, -8592, 368, -656, -632, -228, -176, 0, 1530, 194, 736, 44, 669, -430, 894, -464], [28820, -91296, -3563, 2810, 2112, -290, -450, 1536, -726, -746, 52, 328, -3135, -720, 270, 170, -26, -36, -150, -62], [2165, -51398, 16565, 976, 1490, 8039, 976, 2743, 662, -422, 636, 0, 1660, 221, -575, 134, 425, 120, -39, -81], [-3151, 41337, 17260, 1376, 770, 18994, 1376, -2352, 322, 288, 256, 0, -2400, -289, 80, -416, 126, 305, -609, 304], [-8834, 61036, 6667, 456, -2564, 4635, 456, 7274, -222, 150, -654, 0, -2293, 398, 328, 1146, 492, -36, -476, 512], [58344, 108761, 13194, 779, 708, 2606, -466, -3832, 366, -174, -412, 1244, 3023, -380, 310, 590, 206, -64, 490, 142], [-160880, -77889, -19293, -4576, -1913, -5342, 1008, 6581, -511, -639, -80, 1808, -2500, -679, -656, -776, 40, -24, 72, 16], [5972, -62298, 13467, 848, 2840, 27524, 848, -6066, 466, 174, -752, 0, 1947, -372, -310, -1218, 852, 320, -442, 122], [6477, -91826, -79, -1008, 3812, -19233, -1008, 1835, -376, 680, -1889, 0, 3982, -390, -1002, -264, 1598, 152, -594, 442], [115155, 60631, 1439, -6068, 2877, -3726, 108, 10023, 195, 203, 304, -1310, 3084, 355, 220, -1080, -152, -148, -752, -300], [-147, -19722, 19605, 680, 1576, -18857, 680, 5931, -724, 412, 2685, 0, -1610, -128, -792, 772, -1724, -156, 28, 128], [-3889, 28431, 19036, 496, 3198, -38754, 496, 4888, -706, 96, -2128, 0, -352, 345, -1224, -176, 2082, -305, 169, 136], [-176136, -45507, -22353, 6660, 3717, -2686, 1420, 9423, 63, 823, 136, 2560, -2694, 891, 940, -572, -68, 312, 420, 244], [-347440, 11299, 2419, -573, -3450, -2318, -226, 2062, 1530, -74, -800, 772, 1480, -474, -866, -800, 400, -402, 396, -2], [174740, -57236, 10421, -3306, -2642, 4148, 136, -9350, -724, 612, 84, 472, -3493, 654, 160, 1078, -42, 626, 1126, 584], [5820, -3602, -2145, 80, 886, 67790, 80, -8474, -944, -18, 3280, 0, -765, 437, -302, -898, -931, -481, 543, -62], [-186, 30900, 8761, -272, 5392, -9601, -272, 1010, -1118, -306, -2524, 0, 161, 772, -1946, -1038, 1198, -712, 958, -246], [623296, -16945, 1880, -3591, 4848, 5658, 978, -5644, -174, 766, 100, 4, -2113, 816, 1642, 1486, -50, 420, 690, 370], [7014, -39976, -5981, -1152, 2170, 33234, -1152, -2458, -2132, 374, 2080, 0, 375, 251, -958, -426, -1279, -879, 1133, -254], [2900, -13500, -11478, -832, -1148, 83012, -832, -4672, -1136, -12, -960, 0, -186, -342, 544, -716, -1534, -574, 1502, -928], [-146938, -20185, -11522, -1538, -572, -686, 1274, 748, 962, -282, -1204, 3759, -1777, -884, 234, 278, 602, -20, 1766, 582], [-640931, 73482, -1086, 5012, -8072, -4028, -780, -1096, 680, -1056, -560, 3602, 3380, -1336, -2204, -968, 280, -588, -336, -308], [-3626, 49844, -15604, -1624, 1432, 1519, -1624, 3570, 188, 508, -1746, 0, -426, -1616, 96, 244, 964, 348, 412, -760], [9178, -142694, 20776, -176, 9668, 127188, -176, 5408, 340, 496, -4208, 0, 4352, -114, -2768, -832, -1612, 418, -1218, 800], [-741148, -81791, -49163, 12681, 5022, -5486, 2126, 12982, -366, -146, 352, 4372, -3608, 30, 670, -800, -176, -66, -660, -242], [475150, 100282, 15774, -932, 1675, -3178, -2260, 5905, -2491, -1267, 1232, -6669, 4780, -651, -436, -728, -616, -4, -1856, -620], [-850149, -110556, 30605, 944, -9045, 5125, -1029, -13081, 2145, 2151, -440, 2386, -3566, 1931, -1101, 60, 220, 223, 1106, 443], [-6386, 99524, -28150, -1144, -5352, 28731, -1144, 1834, -496, 104, 2994, 0, -2272, 1256, 796, 1512, 704, -196, -968, 1164], [-639776, 134627, 44120, -3082, 3382, -2674, -2598, 10610, 332, 384, 756, 5785, 5497, 762, -22, -1686, -378, -352, -1838, -730], [370845, -66743, 23028, -2634, 8423, 8436, -1822, -10059, 847, -1757, -692, -342, -921, -2103, 1378, 2054, 346, -956, -874, -610], [4180, -201554, 39665, 3088, -6864, -195740, 3088, 9670, 1102, -950, 3760, 0, 3717, 364, 1490, 2106, -1280, 76, 434, -510], [-156220, -31062, 50894, 5294, -11724, 648, -3808, -9492, -828, 4, 352, 5416, -1280, 180, -2440, -672, -176, 240, -48, 64], [10625, -131098, 14107, 376, 4796, -16482, 376, -4225, -244, -580, -3613, 0, 5448, 906, -1458, -1740, 1130, -412, 498, -86], [1291615, -19683, 53006, -11115, 6517, 11159, -3631, -17823, -1513, -2391, 216, -4466, 566, -2283, 993, 2804, -108, -547, -1418, -655], [985355, 28739, 33565, 2913, 8867, 4415, -2211, 7315, 5275, 1325, -2196, -14698, 5353, 227, 2061, -550, 1098, -877, 1540, 221], [-20685, 271826, 28032, 3992, -1748, 2690, 3992, -9403, 1934, -566, -5213, 0, -10783, 958, 1092, -1802, -2504, 684, -1760, 1076], [-13108, 130116, -15886, -1280, -3466, -38838, -1280, 15032, -782, 798, 2977, 0, -5084, 631, -61, 3026, -1573, 8, -1445, 1437], [-775490, -123304, 10727, 834, 1704, -1870, -3110, -532, -5526, -3098, 2052, -3420, -3793, -2072, -702, 398, -1026, 188, -2702, -838], [-2290, 84988, -67147, -2880, -9438, -42670, -2880, -11478, 528, -726, -1632, 0, 4201, 359, 3054, -182, 8253, -99, 565, -466], [637107, 345870, -33432, 1420, 8006, 14120, 5684, -18510, 238, 3990, 1224, -1960, 6730, 4602, 3508, 3588, -612, 1264, 692, 652], [-12156, 387964, -80275, -5656, 13354, -28985, -5656, -1480, 2744, -1120, -3467, 0, -5891, -2111, -2917, -1680, -1105, 812, 1607, -2419], [21072, -406558, 38753, 368, 4436, -336128, 368, 19838, 642, -1190, 3472, 0, 14677, -286, -2150, 2026, 3570, -274, 2024, -1750], [28999, -383186, -46477, -2624, -14818, 36123, -2624, -16643, -4030, 1342, 5088, 0, 9040, -109, 4399, 386, -2961, -1344, 1455, -111], [-26923, 247013, 36358, 2672, -3392, 218996, 2672, 13520, -300, 652, -2032, 0, -13246, -364, 768, 1628, -5357, 176, -640, 464], [-20941, 355922, -27992, -2712, 2820, 44298, -2712, 11061, -3898, -366, -985, 0, -9295, 3434, -3072, 830, 276, -2132, 1196, 936], [644615, 70832, 97696, -30304, 13108, -3464, -3296, 27996, 1004, 428, -2048, 4076, 960, -596, 3456, -1536, 1024, 736, 4544, 1760], [-5091, 396766, -3499, -200, 11700, -100546, -200, -27325, -3784, 1808, 7663, 0, -17606, -706, -2618, -4128, -5470, -988, 874, 114], [362751, -211359, 26395, 15968, 21227, 11858, -1112, 1393, -3527, 1369, 1208, 5902, -13578, 1973, 5848, 2924, -604, 1844, 1876, 1240], [2742, -282084, 82501, 3592, 7212, -12681, 3592, 12226, 3150, 10, -15690, 0, 9449, -3490, -172, -1626, 3784, 1580, 320, -1900], [2547933, 186443, 22587, -24992, 7595, 1546, -288, 8833, 6421, 341, -3200, -26136, 13600, -1259, 1568, -576, 1600, -1440, 1920, 160], [-1438614, -176737, 67827, 4495, 4632, 20144, -3168, -29064, 3444, -60, -2648, 6088, -7394, -1384, 2264, 4060, 1324, -428, 3116, 896], [353124, 505598, 36804, -16284, -19211, -1438, -564, -13409, 3167, -1513, -3864, -4739, 17394, -3445, -3220, 52, 1932, -408, 4980, 1524], [481130, 461338, 55089, 19576, 19828, 13794, -1902, -4080, -2434, 2186, 2452, 10220, 9427, 3412, 4802, 2422, -1226, 1084, -1510, -142], [25974, -192200, -2501, -3168, 19386, 225842, -3168, -19082, -1252, 1318, -9632, 0, 9935, -4053, -3118, -5946, 4705, 33, 2669, -2702], [-100750, -309240, -111458, -27944, -2928, -27456, 4832, 31840, -11700, -4644, 4776, 3504, -11782, -2256, -2816, -2764, -2388, 1140, -4884, -1248], [-26383, 409566, 16464, 1288, 536, 35842, 1288, 7999, -66, 538, 10351, 0, -15321, -2236, -2, 1942, 1106, 236, 1226, -1462], [688551, -697323, 6790, 16589, -18547, -9057, -3703, 7929, 5839, 2513, -648, -4258, -14754, 2189, -4839, -5116, 324, -1339, -1706, -1015], [1924228, 394814, -25963, 11638, 7374, 15430, 2626, -19958, 6624, 2068, -2148, -21240, 16563, 994, 2386, 2878, 1074, -1204, 814, -130], [-18817, 69346, 45963, 72, -8392, -98178, 72, 23593, -9076, 4012, 2471, 0, -6738, 720, 400, 3940, 6548, -2532, 332, 2200], [-717718, 274084, -118073, 23450, -17600, 2446, 7222, -26852, 1466, -274, -2140, -9036, 6567, -1344, -2282, 2654, 1070, 200, 3610, 1270], [10143, -35581, 38060, 5392, -6346, -185178, 5392, -24972, 2822, -4576, 10960, 0, 6148, 169, 2604, -2512, 12374, -877, 6161, -5284], [-8882, 337832, -44709, -1600, 4554, -46277, -1600, -12682, 1536, -1840, 4191, 0, -2427, 1709, -1637, -1504, 9203, -152, 435, -283], [59355, -562401, -50468, -6080, 17652, 539840, -6080, -20324, -964, -24, 1184, 0, 24944, -486, -4524, -4088, 4427, -494, 1498, -1004], [-3506038, 371384, 22990, -26856, -1072, -23648, 1472, 44576, 2860, 892, 488, 37696, 12250, 1136, -2240, -6604, -244, -1228, -3188, -1472], [-30570, 548614, 80880, 8912, 3272, -307184, 8912, -24768, 3128, -4080, 656, 0, -19376, 588, 272, -5152, 246, -476, 4444, -3968], [-81003, 453350, 110705, 10104, -26776, 72543, 10104, 59731, 5332, -1820, -9731, 0, -19310, 1272, 6112, 8924, 484, 1756, -2964, 1208], [-35193, 892574, -137554, -9288, 20078, -31113, -9288, -2627, 532, -2828, -7754, 0, -13691, 2835, -6995, -3076, 4777, -1148, 2289, -1141], [11729, -300909, 47799, 3120, 5148, -579316, 3120, 4478, 2766, -1770, -12272, 0, 14039, 4354, -2502, -1498, 4533, 498, -3580, 3082], [16906, -450690, 155320, 6640, 20468, 193316, 6640, 31692, 2548, -2000, -2352, 0, 9956, -542, -6572, 64, -3812, 274, 1994, -2268], [793456, 317223, 30623, 19123, -15950, 426, -3138, -16126, -682, 2770, 4864, 8012, 13632, 5202, -5002, -2416, -2432, -706, -8708, -3138], [-2526709, 308870, 29758, -24528, 11957, 19873, -2413, -51115, -9947, -9773, 3140, 18106, 6451, -8203, 307, 8510, -1570, -1483, -7676, -3053], [43691, -337369, 42586, 7616, -3952, -439316, 7616, -52812, 1756, 324, 23008, 0, -1462, 3688, 1532, -3292, -14123, 1040, -6092, 5052], [103, 67602, 131805, 6408, 33488, -38682, 6408, -9487, 2096, 4312, -8585, 0, -11028, -2228, -7424, -5784, -7972, 3204, -8492, 5288], [-4158871, -547965, -175178, -2037, 20035, 34529, 14231, -57449, 9209, 855, -4136, -3886, -18866, -1213, 6295, 10708, 2068, -2109, 1986, -41], [-5214711, 175820, -25131, 74568, -20327, -7241, -10135, -24355, -11185, -9919, 4720, -3394, 9024, -7559, -8551, -248, -2360, -1727, -10534, -4087], [1972, 51682, -48433, -1104, 2788, -432168, -1104, -35774, 5590, 294, -20944, 0, 6187, -3278, 3334, -6570, 6814, 2942, -2900, -42], [-59441, 349815, -41587, -4352, 17145, -23098, -1992, 44283, -10845, -4285, 7880, -7690, 16266, -345, -1080, -4460, -3940, -660, -13140, -4600], [-2834952, 427595, -168292, 62550, -24906, -30978, 11146, 39762, -7932, 6776, 3524, 21425, -2227, 8538, -2438, -5550, -1762, 5592, 5898, 3830], [9259, -465139, 217051, 15344, -2664, 418312, 15344, -9170, -2830, -946, -15504, 0, 4763, 9132, -1334, -4354, -2179, -1888, -4410, 6298], [-55304, 533228, 1724, -4160, 2454, -188158, -4160, 50908, -4954, -22, -15271, 0, -16082, -3185, -1697, 3334, 311, -2488, 8183, -5695], [-20262, 106976, 270753, 16160, 7234, 399634, 16160, -14286, -5256, 898, -2240, 0, -12507, -3577, 102, -6142, 15409, -2179, 7037, -4858], [2043564, -672395, -16023, -23024, -13107, 2086, 448, -17657, -2085, -3269, -3600, -18864, -22820, -5069, -896, 2872, 1800, 1208, 7816, 3008], [-14717, 259658, -190663, -11256, 5424, 85998, -11256, 17381, 11968, -1096, -13261, 0, 10564, -1932, -320, 2904, 6244, 5436, -7844, 2408], [-27052, 515130, 39883, 4976, 6182, 553038, 4976, -14126, 7832, 2790, 17392, 0, -22949, -10143, 3062, 86, -1443, 5311, -3269, -2042], [-9353892, 732598, -62666, 32834, -7124, 20184, 5824, -47724, 1268, 6420, 4912, -4120, 23100, 8876, -872, 3352, -2456, 120, -7128, -2336], [-437, -368410, 250557, 19984, -21234, -118921, 19984, 7481, 1798, 2314, 32232, 0, -15310, -885, 6035, 6070, -13589, 2056, -5541, 3485], [1673, -111113, 64949, 7760, 1828, -56932, 7760, 5234, 8954, -5566, 1936, 0, 11485, 7654, -2794, 594, 8625, 1694, -5476, 3782], [-1637388, 527262, 59361, -16608, 17282, 7728, -4084, -2450, -12380, -2828, 3740, -34616, 14049, -958, 4268, 3778, -1870, 2906, 202, 1036], [-75748, 1169442, 32421, 4432, 25310, 305310, 4432, -9134, 12044, -54, -19728, 0, -32439, -7503, -1930, -6022, 3105, 5995, -4433, -1562], [-307533, 262541, -311496, -14734, 32873, -18388, 21406, 35115, -12131, -3047, 5788, 13644, -2437, -153, 5838, 3102, -2894, 1648, -5386, -1246], [-99340, 865228, 162806, 14288, -18190, 53515, 14288, 34536, 3798, -6038, -19413, 0, -24020, 3477, 3985, 1638, 16017, -1120, 4801, -3681], [8746499, 158128, -76571, -63360, -48345, -8763, 8163, -40133, 11205, -709, -3112, 4010, 17326, -2265, -11917, -1996, 1556, -4401, -4134, -2845], [56844, -1024998, -107375, -1712, -45984, 531092, -1712, -6062, 10286, 426, 28016, 0, 32153, -6576, 15990, 9946, 1136, 5356, -4562, -794], [-3186172, -849917, -77915, -33548, 19595, 43398, 10396, -85151, -1799, -47, 4168, 48912, -36166, 2037, 4508, 12868, -2084, -1208, -8668, -3292], [48360, -1093312, 52385, 904, -15504, 288691, 904, 26680, 2310, 594, 4746, 0, 31207, -7728, 6426, 5406, 2318, 1452, 4230, -5682], [-7316534, -734338, -215350, -14986, -2658, -23782, 19094, 45750, 9006, 7402, -2968, 34796, -29714, 5918, 1342, -4532, 1484, 682, 5816, 2166], [-104603, 1612286, -212103, -6344, -20124, 184110, -6344, -22101, 8368, -2520, -23209, 0, -42258, -4882, 10038, -2184, -4534, 2924, 1554, -4478], [-5127512, 886952, -239575, 162394, -9166, -5336, 9636, 21950, 14320, 8576, -7900, -50144, 27735, 4626, 2364, -2674, 3950, 1078, 14006, 5028], [-3122319, -597903, -70915, 28383, 28157, 78845, 6767, -123131, 5449, 8351, 2492, -52622, -17587, 9597, 10143, 17330, -1246, 205, -3328, -1041], [-3400034, -565726, 295460, -67672, 40170, 1260, -17600, 34062, -3798, -10982, -2184, 62160, -20882, -12074, 5024, 156, 1092, -2500, -1724, -1408], [-841450, 2004088, 258066, 26808, -30139, 36406, -14592, -94849, -1577, -1497, 1768, 7911, 63786, -613, -6208, 5780, -884, -844, -4340, -1728], [-177279, 1559361, 185550, 11248, -29560, -344484, 11248, 125696, -6996, 284, -6672, 0, -65510, 3616, 2064, 16396, -5677, -3356, 2812, 544], [-75209, 630090, 277274, 23496, -29996, -207998, 23496, -25759, -4342, 1166, -5185, 0, -27797, 3226, 9428, -3102, 27656, -1588, -1216, 2804], [-5276333, -527713, 16238, 2138, -42585, -23864, -1482, 13989, 1767, 7635, 5420, 26336, -12641, 10345, -10490, -10042, -2710, 224, -7682, -2486], [-10960858, -1066262, 56329, 39260, -14516, -65498, -14794, 102032, -36490, -8854, 12676, 48044, -52569, -2516, -6370, -11906, -6338, 7480, -4054, 1142], [73003, -1651846, 372454, 18728, 3208, 137883, 18728, -10027, -3602, -1574, -23103, 0, 45431, -8252, 3846, -9082, 21442, -2588, 15002, -12414], [6655774, 747207, -390868, 19730, 75904, 33158, 25254, -32768, -14686, -5090, 5860, -46333, 12397, -2160, 17142, 18082, -2930, 1868, -5054, -1062], [-15061784, 528557, -20122, 48275, 7848, 7286, 1454, 1188, 1170, -2954, -8668, -8188, 5431, -7288, 5902, 4798, 4334, 2272, 17546, 6606], [-4415990, 1063205, 136691, -193739, 67052, -48604, -3716, 142588, 892, -15724, -7184, -32712, 51780, -19316, 8076, -7576, 3592, -4716, 1344, -1124], [60198, -1304480, -178927, -17696, -14032, 80140, -17696, 79414, -3202, -7622, -26592, 0, 62917, 10172, -3470, 8858, 2638, -5412, 8274, -2862]]
